<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Gwared hag assevel deus an diaz titouroù e SQLite ',
	'dump_slogan' => 'Gwared hag assevel deus an diaz titouroù SPIP',
];
